@@ -495,12 +495,15 @@ class Device(object):
         Event processing should look like this::
 
             fd = open("/dev/input/event0", "rb")
+            fcntl.fcntl(fd, fcntl.F_SETFL, os.O_NONBLOCK)  # optional
             ctx = libevdev.Device(fd)
 
             while True:
                 for e in ctx.events():
                     print(e):
 
+                ... other mainloop code ...
+
         This function detects if the file descriptor is in blocking or
         non-blocking mode and adjusts its behavior accordingly. If the file
         descriptor is in nonblocking mode and no events are available, this
@@ -795,7 +798,7 @@ class Device(object):
             d.grab()
             # device is now exclusively grabbed
 
-            fd.close()
+            fd1.close()
             fd2 = open("/dev/input/event0", "rb")
             d.fd = fd2
             # device is now exclusively grabbed
